"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.shouldBeIgnoredAsNotDocumented = void 0;
const index_1 = require("../../models/index");
const comment_js_1 = require("./comment.js");
function hasCommentOnParentAxis(node) {
    let currentNode = node;
    while (currentNode) {
        if (comment_js_1.getRawComment(currentNode)) {
            return true;
        }
        currentNode = currentNode.parent;
    }
    return false;
}
function shouldBeIgnoredAsNotDocumented(node, kind) {
    // never ignore modules, the project, or enum members
    if (kind === index_1.ReflectionKind.Module ||
        kind === index_1.ReflectionKind.Project ||
        kind === index_1.ReflectionKind.EnumMember) {
        return false;
    }
    // do not ignore properties of the object types, that has comment themselves, for example
    //
    // /**
    //  * has docs
    //  */
    //  export SomeType = { prop1 : string }
    //
    // same applies to the inline types for function arguments:
    //
    // function someFunc(arg1 : { prop1 : string, prop2 : number }) {...}
    //
    // The `prop1` from above should be included in the docs, even that it has no documentation
    // Note, that this does not seem to apply to classes and interfaces - for those, even the class/interface
    // has docs, we still want to exclude the undocumented properties
    // Thankfully for object literals the kind of properties seems to be set to ReflectionKind.Variable
    if (kind === index_1.ReflectionKind.Variable && hasCommentOnParentAxis(node)) {
        return false;
    }
    const hasComment = Boolean(comment_js_1.getRawComment(node));
    return !hasComment;
}
exports.shouldBeIgnoredAsNotDocumented = shouldBeIgnoredAsNotDocumented;
//# sourceMappingURL=declaration.js.map